==> flutter_catalogue_widgets-0.0.14.tar.gz: lib/custom-piechart.dart <==
/*
Implementation:

Imports:
import 'custom-pieChart.dart';
import 'package:charts_flutter/flutter.dart' as charts;
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';
charts_flutter: ^0.9.0 dependency is added to pubspec.yaml file.


    Object:
    List<ServicesData> pieChartData = [
      new ServicesData('Active', 30, Colors.orange),
      new ServicesData('Pending', 10, Colors.black),
      new ServicesData('Completed', 40, Colors.red),
      new ServicesData('Requested', 20, Colors.grey),
    ];

    List<charts.Series<ServicesData, String>> pieSeries = [
      new charts.Series<ServicesData, String>(
        id: 'Sales',
        domainFn: (ServicesData sales, _) => sales.serviceType,
        measureFn: (ServicesData sales, _) => sales.serviceNumber,
        colorFn: (ServicesData sales, _) =>
            charts.ColorUtil.fromDartColor(sales.mColor),
        labelAccessorFn: (ServicesData row, _) => '${row.serviceNumber}',
        data: pieChartData,
      )
    ];
    ChartsPie objPieOne = new ChartsPie(pieSeries, 50);

    Object Call:
        body: objPieOne,
*/


import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:charts_flutter/flutter.dart' as charts;
import 'consts.dart' as cons;

class ChartsPie extends StatefulWidget{
 final List<charts.Series<dynamic,dynamic>> chartData;
 final int arcValue;
  ChartsPie(this.chartData,this.arcValue);

  @override
  State<StatefulWidget> createState() {
    return _Chartspie(chartData, arcValue);
  }

}

class _Chartspie extends State<ChartsPie>{
  List<charts.Series<dynamic,dynamic>> chartData;
  int arcValue;
  _Chartspie(this.chartData, this.arcValue);


  @override
  Widget build(BuildContext context) {
    return _createPieChart(chartData, arcValue);
  }

  Widget _createPieChart(List<charts.Series<dynamic,dynamic>> objSeries, int arcValue )
  {
    charts.PieChart mPieChart;

    mPieChart = new charts.PieChart(objSeries,

      animate:true ,
      animationDuration: Duration(seconds: cons.pieAnimationTime),
      defaultRenderer: new charts.ArcRendererConfig(
          arcWidth: arcValue,
          arcRendererDecorators: [
            new charts.ArcLabelDecorator(
              labelPosition: charts.ArcLabelPosition.auto,

            )
          ]
      ),
      behaviors: [
        new charts.DatumLegend(
          position: charts.BehaviorPosition.bottom,
          outsideJustification: charts.OutsideJustification.middleDrawArea,
          horizontalFirst: false,
          desiredMaxRows: cons.pieMaxRows,
        )
      ],
    );
    return mPieChart;
  }
}

==> flutter_catalogue_widgets-0.0.16.tar.gz: lib/custom-piechart.dart <==
/*
Implementation:

Imports:
import 'custom-pieChart.dart';
import 'package:charts_flutter/flutter.dart' as charts;
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';
charts_flutter: ^0.9.0 dependency is added to pubspec.yaml file.


    Object:
    List<ServicesData> pieChartData = [
      new ServicesData('Active', 30, Colors.orange),
      new ServicesData('Pending', 10, Colors.black),
      new ServicesData('Completed', 40, Colors.red),
      new ServicesData('Requested', 20, Colors.grey),
    ];

    List<charts.Series<ServicesData, String>> pieSeries = [
      new charts.Series<ServicesData, String>(
        id: 'Sales',
        domainFn: (ServicesData sales, _) => sales.serviceType,
        measureFn: (ServicesData sales, _) => sales.serviceNumber,
        colorFn: (ServicesData sales, _) =>
            charts.ColorUtil.fromDartColor(sales.mColor),
        labelAccessorFn: (ServicesData row, _) => '${row.serviceNumber}',
        data: pieChartData,
      )
    ];
    ChartsPie objPieOne = new ChartsPie(pieSeries, 50);

    Object Call:
        body: objPieOne,
*/


import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:charts_flutter/flutter.dart' as charts;
import 'package:flutter_catalogue_widgets/consts.dart' as cons;

class ChartsPie extends StatefulWidget{
 final List<charts.Series<dynamic,dynamic>> chartData;
 final int arcValue;
  ChartsPie(this.chartData,this.arcValue);

  @override
  State<StatefulWidget> createState() {
    return _Chartspie(chartData, arcValue);
  }

}

class _Chartspie extends State<ChartsPie>{
  List<charts.Series<dynamic,dynamic>> chartData;
  int arcValue;
  _Chartspie(this.chartData, this.arcValue);


  @override
  Widget build(BuildContext context) {
    return _createPieChart(chartData, arcValue);
  }

  Widget _createPieChart(List<charts.Series<dynamic,dynamic>> objSeries, int arcValue )
  {
    charts.PieChart mPieChart;

    mPieChart = new charts.PieChart(objSeries,

      animate:true ,
      animationDuration: Duration(seconds: cons.pieAnimationTime),
      defaultRenderer: new charts.ArcRendererConfig(
          arcWidth: arcValue,
          arcRendererDecorators: [
            new charts.ArcLabelDecorator(
              labelPosition: charts.ArcLabelPosition.auto,

            )
          ]
      ),
      behaviors: [
        new charts.DatumLegend(
          position: charts.BehaviorPosition.bottom,
          outsideJustification: charts.OutsideJustification.middleDrawArea,
          horizontalFirst: false,
          desiredMaxRows: cons.pieMaxRows,
        )
      ],
    );
    return mPieChart;
  }
}
